@@ -7,4 +7,4 @@
   // omp_set_lock(&RNGlock);
   // omp_unset_lock(&RNGlock);
 //std::vector<std::mt19937_64> rng;
-Rcpp::RNGScope scope;
+//Rcpp::RNGScope scope;
